diff graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/controlflow/SLIfNode.java @ 16855:226552569e34

SL: refactored new naming for condition profiles.
author Christian Humer <christian.humer@gmail.com>
date Mon, 18 Aug 2014 21:02:51 +0200
parents e3724f25056a
children fa5e62620593
line wrap: on
line diff
--- a/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/controlflow/SLIfNode.java	Mon Aug 18 19:02:18 2014 +0200
+++ b/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/controlflow/SLIfNode.java	Mon Aug 18 21:02:51 2014 +0200
@@ -48,11 +48,11 @@
     /**
      * Profiling information, collected by the interpreter, capturing the profiling information of
      * the condition. This allows the compiler to generate better code for conditions that are
      * always true or always false. Additionally the {@link IntegerConditionProfile} implementation
      * (as opposed to {@link BooleanConditionProfile} implementation) transmits the probability of
      * the condition to be true to the compiler.
      */
-    private final ConditionProfile condition = new IntegerConditionProfile();
+    private final ConditionProfile condition = new CountingConditionProfile();
 
     public SLIfNode(SourceSection src, SLExpressionNode conditionNode, SLStatementNode thenPartNode, SLStatementNode elsePartNode) {
         super(src);
@@ -48,11 +48,11 @@
      * Profiling information, collected by the interpreter, capturing the profiling information of
      * the condition. This allows the compiler to generate better code for conditions that are
-     * always true or always false. Additionally the {@link IntegerConditionProfile} implementation
-     * (as opposed to {@link BooleanConditionProfile} implementation) transmits the probability of
+     * always true or always false. Additionally the {@link CountingConditionProfile} implementation
+     * (as opposed to {@link BinaryConditionProfile} implementation) transmits the probability of
      * the condition to be true to the compiler.
      */